<?php
/**
 * Class for getting module options
 *
 * @package aixVeristore
 * @author AIXhibit AG
 * @link http://www.aixhibit.de
 * @copyright (C) 2014, AIXhibit AG
 * @license http://www.gnu.org/licenses/gpl-3.0.txt GPL
 * @extends oxviewconfig
 */
class aixVeristoreOxViewConfig extends aixVeristoreOxViewConfig_parent
{
    /**
     * @var string URL to javascript of the Veristore widget
     */
    private $sWidgetScriptUrl = '//www.veristore.de/app/widget/veristore.min.js';

    /*
     * @var string Best rating possible
     */
    private $sVsMaxRating;

    /**
     * @var string Actual rating for this customer
     */
    private $sVsActRating;

    /**
     * @var int Number of accepted ratings for this customer
     */
    private $iVsRatingCount;
    
    /**
     * @var string Shop-URL
     */
    private $sVsShopUrl;

    /**
     * @var string URL of Veristore certificate
     */
    private $sVsCertUrl;

    public function __construct()
    {
        parent::__construct();
        $this->getVsStructData();
    }

    /**
     * Returns the URL of the widgets javascript
     *
     * @return string
     */
    public function getVsWidgetScriptUrl()
    {
        return $this->sWidgetScriptUrl;
    }

    /**
     * Returns maximum rating
     *
     * @return mixed
     */
    public function getSVsMaxRating()
    {
        return $this->sVsMaxRating;
    }

    /**
     * Returns actual rating
     *
     * @return string
     */
    public function getSVsActRating()
    {
        return $this->sVsActRating;
    }

    /**
     * Returns number of ratings
     *
     * @return int
     */
    public function getIVsRatingCount()
    {
        return $this->iVsRatingCount;
    }

    /**
     * Returns shops URL
     *
     * @return string
     */
    public function getSVsShopUrl()
    {
        return $this->sVsShopUrl;
    }

    /**
     * Returns URL of shops certificate
     *
     * @return string
     */
    public function getSVsCertUrl()
    {
        return $this->sVsCertUrl;
    }

    /**
     * Returns Veristore token
     *
     * @return string
     */
    public function getVeristoreToken()
    {
        return oxConfig::getInstance()->getShopConfVar('sAixToken', null, 'module:aixVeristore');
    }

    /**
     * Returns widget variant (size)
     *
     * @return type
     */
    public function getVsVariant()
    {
        return oxConfig::getInstance()->getShopConfVar('sAixVariant', null, 'module:aixVeristore');
    }

    /**
     * Returns widget position
     *
     * @return string
     */
    public function getVsPosition()
    {
        return oxConfig::getInstance()->getShopConfVar('sAixVsPosition', null, 'module:aixVeristore');
    }

    /**
     * Returns offset for widget
     *
     * @return type
     */
    public function getVsOffset()
    {
        return oxConfig::getInstance()->getShopConfVar('iAixOffset', null, 'module:aixVeristore');
    }

    /**
     * Returns if widget shall be responsive
     *
     * @return type
     */
    public function getVsIsResponsive()
    {
        return oxConfig::getInstance()->getShopConfVar('blAixResponsive', null, 'module:aixVeristore');
    }

    /**
     * Returns if structured data shall be displayed
     *
     * @return bool
     */
    public function isStructDataActive()
    {
        return oxConfig::getInstance()->getShopConfVar('blAixVsStructData', null, 'module:aixVeristore');
    }

    /**
     * Gets the structured data from Veristore
     *
     * @return bool
     */
    public function getVsStructData()
    {
        if ($this->isStructDataActive()) {

            $curlHandle = curl_init();

            //set url
            $sUrl = 'https://www.veristore.de/app/s/' . $this->getVeristoreToken() . '/shopdata.json';
            curl_setopt($curlHandle, CURLOPT_URL, $sUrl);

            //return the transfer as a string
            curl_setopt($curlHandle, CURLOPT_RETURNTRANSFER, 1);

            curl_setopt($curlHandle, CURLOPT_FAILONERROR, true);
            curl_setopt($curlHandle, CURLOPT_FOLLOWLOCATION, true);
            curl_setopt($curlHandle, CURLOPT_SSL_VERIFYHOST, false);
            curl_setopt($curlHandle, CURLOPT_SSL_VERIFYPEER, false);

            //$output contains the output string
            $sOutput = curl_exec($curlHandle);
            //$this->aixLog($sOutput);
            if ($sOutput !== false) {
                $oStructData = json_decode($sOutput);
                //$this->aixLog('URL: '.$oStructData->url);
                $this->sVsShopUrl = trim($oStructData->url);
                $this->sVsMaxRating = '5,0';
                $this->sVsActRating = $oStructData->score;
                $this->iVsRatingCount = $oStructData->ratings;
                $this->sVsCertUrl = 'https://www.veristore.de/app/zertifikat/' . $this->getVeristoreToken();
            }

            //close curl resource to free up system resources
            curl_close($curlHandle);
        }
    }

    private function aixLog($sMessage)
    {
        $oConfig = oxRegistry::getConfig();


        $sLogFileName = 'veristore.log';
        $sLogFilePath = $oConfig->getLogsDir() . $sLogFileName;
        $sLogDate = "[" . date('Y-m-d H:i:s') . "] ";
        file_put_contents($sLogFilePath, $sLogDate . $sMessage."\n", FILE_APPEND);
    }
}